@@ -13,6 +13,7 @@ test_that("PipeOp - General functions", {
   expect_equal(po_1$packages, "mlr3pipelines")
   expect_null(po_1$state)
   assert_subset(po_1$tags, mlr_reflections$pipeops$valid_tags)
+  expect_error(po_1$predict(list(tsk("iris"))), "has not been trained yet")
 
   expect_output(expect_equal(po_1$train(list(1)), list(output = 1)), "Training debug.basic")
   expect_equal(po_1$state, list(input = 1))
@@ -95,14 +96,16 @@ test_that("Informative error and warning messages", {
 
   expect_no_warning(suppressWarnings(gr$predict(tsk("iris"))))
 
-
   gr$param_set$values$classif.debug.warning_train = 0
   gr$param_set$values$classif.debug.warning_predict = 0
+  
   gr$param_set$values$classif.debug.error_train = 1
-  gr$param_set$values$classif.debug.error_predict = 1
-
   expect_error(gr$train(tsk("iris")), "This happened PipeOp classif.debug's \\$train\\(\\)$")
 
+  gr$param_set$values$classif.debug.error_train = 0
+  gr$param_set$values$classif.debug.error_predict = 1
+  # Need to first train the Graph for predict to work
+  gr$train(tsk("iris"))
   expect_error(gr$predict(tsk("iris")), "This happened PipeOp classif.debug's \\$predict\\(\\)$")
 
   potest = R6::R6Class("potest", inherit = PipeOp,
