@@ -19,6 +19,7 @@ test_that("PipeOpClassWeights", {
   nt = op$train(list(task))[[1L]]
   expect_equal(nt$data(), task$data())
 
-  expect_equal(nt$weights$weight, ifelse(nt$truth(nt$weights$row_ids) == "neg", 1, 3))
+  weights = if ("weights_learner" %in% names(nt)) "weights_learner" else "weights"
+  expect_equal(nt[[weights]]$weight, ifelse(nt$truth(nt[[weights]]$row_ids) == "neg", 1, 3))
 
 })
